@@ -5,12 +5,13 @@ from ..parser import extract_assign_targets
 
 
 class LocalsGatherer(SemanticVisitor):
-    def __init__(self):
+    def __init__(self, source_path):
+        self.source_path = source_path
         self.names = []
 
     @classmethod
-    def gather(cls, nodes):
-        instance = cls()
+    def gather(cls, nodes, source_path):
+        instance = cls(source_path)
         instance._iterate_nodes(nodes)
         return instance.names
 
@@ -18,7 +19,7 @@ class LocalsGatherer(SemanticVisitor):
         self.names.append(node.name)
 
     def visit_assign(self, node: ast.Assign):
-        self.names.extend(extract_assign_targets(node.targets))
+        self.names.extend(extract_assign_targets(node.targets, self.source_path))
 
     def generic_visit(self, node: ast.AST, *args, **kwargs):
         pass
